@@ -74,10 +74,10 @@ std::pair<std::string, int > get_peer_name(int sock) {
   return std::make_pair(std::string(result_addr), port);
 }
 
-std::vector<string> split_string(const string& data, const char delimiter, bool allow_empty) {
+std::vector<std::string> split_string(const std::string& data, const char delimiter, bool allow_empty) {
   std::stringstream ss(data);
   std::string token;
-  std::vector<string> result;
+  std::vector<std::string> result;
 
   if (data.empty()) {
     return {};
@@ -99,15 +99,27 @@ std::vector<string> split_string(const string& data, const char delimiter, bool
   return result;
 }
 
-std::vector<string> split_string(const string& data, const char delimiter) {
+std::vector<std::string> split_string(const std::string& data, const char delimiter) {
   return split_string(data, delimiter, true);
 }
 
-std::array<uint8_t, 16> in6_addr_to_array(in6_addr addr) {
-  std::array<uint8_t, 16> result;
-  for (int i = 0; i < 16; ++i) {
-    std::memcpy(result.data(), addr.s6_addr, 16);
+std::array<uint8_t, 16> in_addr_to_array(const sockaddr_storage &addr) {
+  std::array<uint8_t, 16> result{{0}};
+
+  switch (addr.ss_family) {
+  case AF_INET6:
+    {
+      const sockaddr_in6 *addr_intet6 = reinterpret_cast<const sockaddr_in6*>(&addr);
+      std::memcpy(result.data(), &addr_intet6->sin6_addr, sizeof(addr_intet6->sin6_addr));
+      break;
+    }
+  default:
+    {
+      const sockaddr_in *addr_intet = reinterpret_cast<const sockaddr_in*>(&addr);
+      std::memcpy(result.data(), &addr_intet->sin_addr, sizeof(addr_intet->sin_addr));
+    }
   }
+
   return result;
 }
 
